"use strict";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var fs = require('fs');

var Path = require('path');

var Url = require('url');

var http = require('http');

var https = require('https');

var lcov = require('../lib/parsers/lcov');

var cobertura = require('../lib/parsers/cobertura');

var golang = require('../lib/parsers/golang');

var jacoco = require('../lib/parsers/jacoco');

var git = require('../lib/git');

var ci = require('../lib/ci');

module.exports = function cli(_ref) {
  var parser = _ref.parser,
      input = _ref.input,
      url = _ref.url,
      basePath = _ref.basePath;
  var parsedUrl = Url.parse(url);
  return new Promise(
  /*#__PURE__*/
  function () {
    var _ref2 = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee(resolve, reject) {
      var info, env, output, i, path, options, operation, data, req;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return git.parse();

            case 3:
              info = _context.sent;
              env = ci();
              output = {
                service_job_id: env.service_job_id,
                service_pull_request: env.service_pull_request,
                service_name: env.service_name,
                source_files: [],
                git: {
                  author_date: info.author_date,
                  author_email: info.author_email,
                  author_name: info.author_name,
                  committer_date: info.committer_date,
                  commit: env.commit || info.commit,
                  branch: env.branch || info.branch,
                  message: env.message || info.message,
                  committer_name: env.committer_name || info.committer_name,
                  committer_email: env.committer_email || info.committer_email,
                  remotes: info.remotes
                },
                run_at: new Date()
              };
              _context.t0 = parser;
              _context.next = _context.t0 === 'cobertura' ? 9 : _context.t0 === 'golang' ? 13 : _context.t0 === 'jacoco' ? 17 : 21;
              break;

            case 9:
              _context.next = 11;
              return cobertura.parse(input);

            case 11:
              output['source_files'] = _context.sent;
              return _context.abrupt("break", 25);

            case 13:
              _context.next = 15;
              return golang.parse(input);

            case 15:
              output['source_files'] = _context.sent;
              return _context.abrupt("break", 25);

            case 17:
              _context.next = 19;
              return jacoco.parse(input);

            case 19:
              output['source_files'] = _context.sent;
              return _context.abrupt("break", 25);

            case 21:
              _context.next = 23;
              return lcov.parse(input);

            case 23:
              output['source_files'] = _context.sent;
              return _context.abrupt("break", 25);

            case 25:
              i = 0;

            case 26:
              if (!(i < output['source_files'].length)) {
                _context.next = 37;
                break;
              }

              path = basePath ? Path.resolve(process.cwd(), basePath, output['source_files'][i].file) : output['source_files'][i].file;

              if (!fs.existsSync(path)) {
                _context.next = 33;
                break;
              }

              output['source_files'][i].source = fs.readFileSync(path).toString('utf8');
              output['source_files'][i].title = output['source_files'][i].file.substring(output['source_files'][i].file.lastIndexOf('/') + 1, output['source_files'][i].file.length);
              _context.next = 34;
              break;

            case 33:
              return _context.abrupt("return", reject("can not find file at ".concat(path)));

            case 34:
              i++;
              _context.next = 26;
              break;

            case 37:
              options = {
                hostname: parsedUrl.hostname,
                port: parsedUrl.port || 80,
                path: '/api/upload',
                method: 'POST',
                headers: {
                  'Content-Type': 'application/json'
                }
              };
              operation = http;
              data = '';

              if (parsedUrl.protocol == 'https:') {
                options.port = 443;
                operation = https;
              }

              req = operation.request(options, function (res) {
                res.on('data', function (chunk) {
                  data += chunk;
                });
                res.on('end', function () {
                  try {
                    var response = JSON.parse(data);

                    if (response.error) {
                      return reject(response.error); // eslint-disable-line
                    } else {
                      return resolve(response);
                    }
                  } catch (ex) {
                    return reject(ex);
                  }
                });
              });
              req.write(JSON.stringify(output));
              req.end();
              _context.next = 49;
              break;

            case 46:
              _context.prev = 46;
              _context.t1 = _context["catch"](0);
              return _context.abrupt("return", reject(_context.t1));

            case 49:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[0, 46]]);
    }));

    return function (_x, _x2) {
      return _ref2.apply(this, arguments);
    };
  }());
};